@@ -1,8 +1,8 @@
-"""Top-level package for rna."""
+"""Top-level package of rna."""
 
 __author__ = """Daniel Böckenhoff"""
 __email__ = "dboe@ipp.mpg.de"
-__version__ = "0.5.0"
+__version__ = "0.6.0"
 
 from . import plotting
 from . import log  # NOQA
