@@ -54,9 +54,9 @@ def gca(dim=None, **kwargs):
         >>> assert axes_dim(ax_2) == 2
 
     """
-    if dim is not None and 'projection' not in kwargs:
+    if dim is not None and "projection" not in kwargs:
         if dim == 2:
-            kwargs['projection'] = 'rectilinear'
+            kwargs["projection"] = "rectilinear"
             # the line above would already be good ...
             # but there is a bug in matplotlib which ignores setting the default
             axes = plt.gca(**kwargs)
@@ -65,10 +65,11 @@ def gca(dim=None, **kwargs):
             else:
                 return axes
         elif dim == 3:
-            kwargs['projection'] = '3d'
+            kwargs["projection"] = "3d"
         else:
-            raise NotImplementedError("Dimension {dim} not implemented"
-                                      .format(**locals()))
+            raise NotImplementedError(
+                "Dimension {dim} not implemented".format(**locals())
+            )
     axes = plt.gca(**kwargs)
     return axes
 
@@ -99,14 +100,13 @@ def upgrade_style(style, source, dest=None):
     """
     if dest is None:
         dest = mpl.get_configdir()
-    style_extension = 'mplstyle'
-    path = rna.path.resolve(os.path.join(dest,
-                                         style + '.' + style_extension))
+    style_extension = "mplstyle"
+    path = rna.path.resolve(os.path.join(dest, style + "." + style_extension))
     source = rna.path.resolve(source)
     rna.path.cp(source, path)
 
 
-def set_style(style='rna', dest=None, upgrade=False):
+def set_style(style="rna", dest=None, upgrade=False):
     """
     Set the matplotlib style of name
     Important:
@@ -119,8 +119,8 @@ def set_style(style='rna', dest=None, upgrade=False):
     if dest is None:
         dest = mpl.get_configdir()
 
-    style_extension = 'mplstyle'
-    path = rna.path.resolve(os.path.join(dest, style + '.' + style_extension))
+    style_extension = "mplstyle"
+    path = rna.path.resolve(os.path.join(dest, style + "." + style_extension))
     if style in mpl.style.available and not upgrade:
         plt.style.use(style)
     elif os.path.exists(path) and not upgrade:
@@ -129,21 +129,24 @@ def set_style(style='rna', dest=None, upgrade=False):
         log = logging.getLogger()
         source = rna.path.resolve(
             os.path.join(
-                os.path.join(os.path.dirname(__file__), 'mplstyles'),
-                style + '.' + style_extension))
+                os.path.join(os.path.dirname(__file__), "mplstyles"),
+                style + "." + style_extension,
+            )
+        )
         if os.path.exists(source):
-            log.warning("I will copy the style {style} to {dest}."
-                        .format(**locals()))
+            log.warning("I will copy the style {style} to {dest}.".format(**locals()))
             try:
                 upgrade_style(style, source, dest)
                 set_style(style)
             except Exception:
                 log.error("Could not set style")
         else:
-            log.error("Could not set style {path}. Probably you would want to"
-                      "call rna.plotting.upgrade_style(<style>, "
-                      "<path to mplstyle file that should be copied>)"
-                      "once".format(**locals()))
+            log.error(
+                "Could not set style {path}. Probably you would want to"
+                "call rna.plotting.upgrade_style(<style>, "
+                "<path to mplstyle file that should be copied>)"
+                "once".format(**locals())
+            )
 
 
 def _save(path, **kwargs):
@@ -162,7 +165,7 @@ def _save(path, **kwargs):
 
     """
     # catch figure from axes or fig
-    axes = kwargs.get('axes', None)
+    axes = kwargs.get("axes", None)
     if axes is None:
         fig_default = plt.gcf()
         axes = gca()
@@ -170,21 +173,20 @@ def _save(path, **kwargs):
             raise ValueError("fig_default may not be None")
     else:
         fig_default = axes.figure
-    fig = kwargs.get('fig', fig_default)
+    fig = kwargs.get("fig", fig_default)
 
     # resize the figure to match a given width (in pt).
-    width = kwargs.pop('width', None)
-    scale = kwargs.pop('scale', 1.)
+    width = kwargs.pop("width", None)
+    scale = kwargs.pop("scale", 1.0)
     orig_size = fig.get_size_inches()
     orig_ratio = orig_size[1] / orig_size[0]
-    ratio = kwargs.pop('ratio', orig_ratio)
+    ratio = kwargs.pop("ratio", orig_ratio)
     if width is not None:
-        fig.set_size_inches(*rna.plotting.figsize(width, scale=scale,
-                                                  ratio=ratio))
+        fig.set_size_inches(*rna.plotting.figsize(width, scale=scale, ratio=ratio))
 
     # crop the plot down based on the extents of the artists in the plot
-    kwargs['bbox_inches'] = kwargs.pop('bbox_inches', 'tight')
-    if kwargs['bbox_inches'] == 'tight':
+    kwargs["bbox_inches"] = kwargs.pop("bbox_inches", "tight")
+    if kwargs["bbox_inches"] == "tight":
         extra_artists = None
         for ax in fig.get_axes():
             first_label = ax.get_legend_handles_labels()[0] or None
@@ -195,42 +197,43 @@ def _save(path, **kwargs):
                     extra_artists.extend(first_label)
                 else:
                     extra_artists.append(first_label)
-        kwargs['bbox_extra_artists'] = kwargs.pop('bbox_extra_artists',
-                                                  extra_artists)
+        kwargs["bbox_extra_artists"] = kwargs.pop("bbox_extra_artists", extra_artists)
 
     # pgf post-processing works but matpltolib pgf backend writes pgftext left
     # adjusted and creates right adjusted text by moving the text in x
     # this makes it impossible to rescale text correctly. If one knew, the
     # original was right adjusted a correction could be applied. This way
     # however, we cann not do anything.
-    post_process = kwargs.pop('post_process', False)
+    post_process = kwargs.pop("post_process", False)
     pgf_kwargs = {
-        'substitutes': kwargs.pop('substitutes', [(r"\sffamily", '')]),
-        'scaling': kwargs.pop('scaling', r"\igraph@width"),
-        }
+        "substitutes": kwargs.pop("substitutes", [(r"\sffamily", "")]),
+        "scaling": kwargs.pop("scaling", r"\igraph@width"),
+    }
 
     # set current figure
     plt.figure(fig.number)
 
-    if path.endswith('tikz'):
+    if path.endswith("tikz"):
         import matplotlib2tikz as tikz
+
         if width is None:
             figurewidth = r"\textwidth"
         else:
-            figurewidth = '{0}pt'.format(scale*width)
+            figurewidth = "{0}pt".format(scale * width)
         tikz.save(path, figurewidth=figurewidth)
     else:
         plt.savefig(path, **kwargs)
 
-    if post_process and path.endswith('pgf'):
+    if post_process and path.endswith("pgf"):
         # use it like \igraph[width=0.5\columnwidth]{path_to_the.pgf}
-        substitutes = pgf_kwargs.pop('substitutes')
-        scaling = pgf_kwargs.pop('scaling')
-        with open(path, 'r') as f:
+        substitutes = pgf_kwargs.pop("substitutes")
+        scaling = pgf_kwargs.pop("scaling")
+        with open(path, "r") as f:
             content = []
             exp = r"(\\pgftext.+)(\\fontsize{.+)\\selectfont(.+)}%"
-            exp_width = (r"\\pgfpathrectangle{\\pgfpointorigin}"
-                         r"{\\pgfqpoint{(.+)}{(.+)}%")
+            exp_width = (
+                r"\\pgfpathrectangle{\\pgfpointorigin}" r"{\\pgfqpoint{(.+)}{(.+)}%"
+            )
             for line in f:
                 res = re.match(exp, line)
                 res_width = re.match(exp_width, line)
@@ -238,19 +241,21 @@ def _save(path, **kwargs):
                     pgf_path_size = res_width.groups()[0]
                     # factor 72.27 (latex definition differs from pdf
                     # definition) for conversion from in to pt
-                    pgf_path_size = (r'('
-                                     + pgf_path_size.replace('in', '*72.27')
-                                     + r')')
+                    pgf_path_size = r"(" + pgf_path_size.replace("in", "*72.27") + r")"
                 if res:
                     groups = res.groups()
-                    line = (groups[0]
-                            + r"\selectfont \scalebox{\fpeval{(%s/(%s))}}{" % (
-                                pgf_path_size, scaling)
-                            + groups[2] + r"}}%" + '\n')
+                    line = (
+                        groups[0]
+                        + r"\selectfont \scalebox{\fpeval{(%s/(%s))}}{"
+                        % (pgf_path_size, scaling)
+                        + groups[2]
+                        + r"}}%"
+                        + "\n"
+                    )
                 for x, y in substitutes:
                     line = line.replace(x, y)
                 content.append(line)
-        with open(path, 'w') as f:
+        with open(path, "w") as f:
             f.writelines(content)
 
     # reset the figure size
@@ -276,19 +281,16 @@ def plot_array(array, **kwargs):
         Better Artist not list of Artists
     """
     array = np.array(array)
-    kwargs.setdefault('method', 'scatter')
+    kwargs.setdefault("method", "scatter")
     plot_manager = rna.plotting.PlotManager(kwargs)
 
-    labels = plot_manager.pop('labels', ['x (m)', 'y (m)', 'z (m)'])
+    labels = plot_manager.pop("labels", ["x (m)", "y (m)", "z (m)"])
     x_index, y_index, z_index = plot_manager.get_axis_indices()
     set_labels(plot_manager.axes, *plot_manager.sort_labels(labels))
     if z_index is None:
-        args = [array[:, x_index],
-                array[:, y_index]]
+        args = [array[:, x_index], array[:, y_index]]
     else:
-        args = [array[:, x_index],
-                array[:, y_index],
-                array[:, z_index]]
+        args = [array[:, x_index], array[:, y_index], array[:, z_index]]
     artist = plot_manager.method(*args, **plot_manager.plot_kwargs)
     return artist
 
@@ -319,11 +321,10 @@ def plot_mesh(vertices, faces, **kwargs):
     if po.dim == 2:
         full = True
         import tfields
+
         mesh = tfields.Mesh3D(vertices, faces=faces)
         x_index, y_index, z_index = po.get_axis_indices()
-        facecolors = po.retrieve_chain('facecolors', 'color',
-                                       default=0,
-                                       keep=False)
+        facecolors = po.retrieve_chain("facecolors", "color", default=0, keep=False)
         if full:
             # implementation that will sort the triangles by z_index
             centroids = mesh.centroids()
@@ -342,14 +343,15 @@ def plot_mesh(vertices, faces, **kwargs):
                 zs, faces = tfields.lib.util.multi_sort(zs, faces)
             else:
                 zs, faces, facecolors = tfields.lib.util.multi_sort(
-                    zs, faces, facecolors)
+                    zs, faces, facecolors
+                )
 
             n_faces_initial = len(faces)
         else:
             # cut away "back sides" implementation
-            direction_vector = np.array([1., 1., 1.])
-            direction_vector[x_index] = 0.
-            direction_vector[y_index] = 0.
+            direction_vector = np.array([1.0, 1.0, 1.0])
+            direction_vector[x_index] = 0.0
+            direction_vector[y_index] = 0.0
             norm_vectors = mesh.triangles().norms()
             dot_product = np.dot(norm_vectors, direction_vector)
             n_faces_initial = len(faces)
@@ -357,29 +359,28 @@ def plot_mesh(vertices, faces, **kwargs):
 
         vertices = mesh
 
-        po.plot_kwargs['method'] = 'tripcolor'
-        po.plot_kwargs['triangles'] = faces
+        po.plot_kwargs["method"] = "tripcolor"
+        po.plot_kwargs["triangles"] = faces
 
         """
         sort out color arguments
         """
-        facecolors = po.format_colors(facecolors,
-                                      fmt='norm',
-                                      length=n_faces_initial)
+        facecolors = po.format_colors(facecolors, fmt="norm", length=n_faces_initial)
         if not full:
             facecolors = facecolors[dot_product > 0]
-        po.plot_kwargs['facecolors'] = facecolors
+        po.plot_kwargs["facecolors"] = facecolors
 
         d = po.plot_kwargs
-        d['x_index'] = x_index
-        d['y_index'] = y_index
+        d["x_index"] = x_index
+        d["y_index"] = y_index
         artist = plot_array(vertices, **d)
     elif po.dim == 3:
-        label = po.pop('label', None)
-        color = po.retrieve_chain('color', 'c', 'facecolors',
-                                  default='grey',
-                                  keep=False)
+        label = po.pop("label", None)
+        color = po.retrieve_chain(
+            "color", "c", "facecolors", default="grey", keep=False
+        )
         from rna.plotting.colors import color_fmt
+
         orig_fmt = color_fmt(color)
         orig_color = color
 
@@ -389,16 +390,14 @@ def plot_mesh(vertices, faces, **kwargs):
             color = color[~nanMask]
             faces = faces[~nanMask]
 
-        color = po.format_colors(color,
-                                 fmt='rgba',
-                                 length=len(faces))
+        color = po.format_colors(color, fmt="rgba", length=len(faces))
 
-        edgecolor = po.pop('edgecolor', None)
-        alpha = po.pop('alpha', None)
+        edgecolor = po.pop("edgecolor", None)
+        alpha = po.pop("alpha", None)
         # delete norm arguments
-        po.pop('vmin', None)
-        po.pop('vmax', None)
-        po.pop('cmap', None)
+        po.pop("vmin", None)
+        po.pop("vmax", None)
+        po.pop("cmap", None)
 
         triangles = np.array([vertices[face] for face in faces])
         artist = plt3D.art3d.Poly3DCollection(triangles, **po.plot_kwargs)
@@ -409,7 +408,7 @@ def plot_mesh(vertices, faces, **kwargs):
             artist.set_facecolors(color.tolist())
         else:
             artist.set_color(color.tolist())
-        if orig_fmt == 'norm':
+        if orig_fmt == "norm":
             # sets vmin, vmax to min, max of val
             artist.set_array(np.array(orig_color))
         if alpha is not None:
@@ -426,7 +425,7 @@ def plot_mesh(vertices, faces, **kwargs):
         artist._edgecolors2d = None
         artist._facecolors2d = None
 
-        labels = ['x (m)', 'y (m)', 'z (m)']
+        labels = ["x (m)", "y (m)", "z (m)"]
         set_labels(po.axes, *po.sort_labels(labels))
     else:
         raise NotImplementedError("Dimension != 2|3")
@@ -461,24 +460,37 @@ def plot_tensor_field(points, field, **kwargs):
             raise NotImplementedError(
                 "Probably you used plot instead of"
                 "scatter. This is not yet implemented because you have n-1"
-                "segments but gave n colors.")
+                "segments but gave n colors."
+            )
     elif len(field.shape) == 2:
         # vector
         if points is None:
-            points = np.full(field.shape, 0.)
+            points = np.full(field.shape, 0.0)
         x_index, y_index, z_index = po.get_axis_indices()
         artists = []
         for point, vector in zip(points, field):
             if po.dim == 3:
                 artists.append(
                     po.axes.quiver(
-                        point[x_index], point[y_index], point[z_index],
-                        vector[x_index], vector[y_index], vector[z_index],
-                        **po.plot_kwargs))
+                        point[x_index],
+                        point[y_index],
+                        point[z_index],
+                        vector[x_index],
+                        vector[y_index],
+                        vector[z_index],
+                        **po.plot_kwargs
+                    )
+                )
             elif po.dim == 2:
-                artists.append(po.axes.quiver(point[x_index], point[y_index],
-                                              vector[x_index], vector[y_index],
-                                              **po.plot_kwargs))
+                artists.append(
+                    po.axes.quiver(
+                        point[x_index],
+                        point[y_index],
+                        vector[x_index],
+                        vector[y_index],
+                        **po.plot_kwargs
+                    )
+                )
             else:
                 raise NotImplementedError("Dimension != 2|3")
     else:
@@ -487,16 +499,15 @@ def plot_tensor_field(points, field, **kwargs):
 
 
 def plot_plane(point, normal, **kwargs):
-
-    def plot_vector(fig, orig, v, color='blue'):
-        axes = fig.gca(projection='3d')
+    def plot_vector(fig, orig, v, color="blue"):
+        axes = fig.gca(projection="3d")
         orig = np.array(orig)
         v = np.array(v)
         axes.quiver(orig[0], orig[1], orig[2], v[0], v[1], v[2], color=color)
         axes.set_xlim(0, 10)
         axes.set_ylim(0, 10)
         axes.set_zlim(0, 10)
-        axes = fig.gca(projection='3d')
+        axes = fig.gca(projection="3d")
         return fig
 
     def rotation_matrix(d):
@@ -506,12 +517,11 @@ def plot_plane(point, normal, **kwargs):
         d /= sin_angle
         eye = np.eye(3)
         ddt = np.outer(d, d)
-        skew = np.array([[0, d[2], -d[1]],
-                         [-d[2], 0, d[0]],
-                         [d[1], -d[0], 0]],
-                        dtype=np.float64)
+        skew = np.array(
+            [[0, d[2], -d[1]], [-d[2], 0, d[0]], [d[1], -d[0], 0]], dtype=np.float64
+        )
 
-        M = ddt + np.sqrt(1 - sin_angle**2) * (eye - ddt) + sin_angle * skew
+        M = ddt + np.sqrt(1 - sin_angle ** 2) * (eye - ddt) + sin_angle * skew
         return M
 
     def pathpatch_2d_to_3d(pathpatch, z, normal):
@@ -534,13 +544,14 @@ def plot_plane(point, normal, **kwargs):
         d = np.cross(normal, (0, 0, 1))  # Obtain the rotation vector
         M = rotation_matrix(d)  # Get the rotation matrix
 
-        pathpatch._segment3d = np.array([np.dot(M, (x, y, 0)) + (0, 0, z)
-                                         for x, y in verts])
+        pathpatch._segment3d = np.array(
+            [np.dot(M, (x, y, 0)) + (0, 0, z) for x, y in verts]
+        )
 
     def pathpatch_translate(pathpatch, delta):
         pathpatch._segment3d += delta
 
-    kwargs['alpha'] = kwargs.pop('alpha', 0.5)
+    kwargs["alpha"] = kwargs.pop("alpha", 0.5)
     po = rna.plotting.PlotManager(kwargs)
     patch = Circle((0, 0), **po.plot_kwargs)
     po.axes.add_patch(patch)
@@ -571,15 +582,15 @@ def plot_function(fun, **kwargs):
         Better Artist not list of Artists
     """
     import numpy as np
-    labels = ['x', 'f(x)']
+
+    labels = ["x", "f(x)"]
     po = rna.plotting.PlotManager(kwargs)
     rna.plotting.set_labels(po.axes, *labels)
-    xMin, xMax = po.pop('xMin', 0), po.pop('xMax', 1)
-    n = po.pop('n', 100)
+    xMin, xMax = po.pop("xMin", 0), po.pop("xMax", 1)
+    n = po.pop("n", 100)
     vals = np.linspace(xMin, xMax, n)
     args = (vals, map(fun, vals))
-    artist = po.axes.plot(*args,
-                          **po.plot_kwargs)
+    artist = po.axes.plot(*args, **po.plot_kwargs)
     return artist
 
 
@@ -593,7 +604,7 @@ def plot_errorbar(points, errors_up, errors_down=None, **kwargs):
         Better Artist not list of Artists
     """
     po = rna.plotting.PlotManager(kwargs)
-    po.setdefault('marker', '_')
+    po.setdefault("marker", "_")
 
     if errors_down is None:
         errors_down = errors_up
@@ -606,23 +617,29 @@ def plot_errorbar(points, errors_up, errors_down=None, **kwargs):
     # plot errorbars
     for i in range(len(points)):
         artists.append(
-            po.axes.plot([points[i, 0] + errors_up[i, 0],
-                          points[i, 0] - errors_down[i, 0]],
-                         [points[i, 1], points[i, 1]],
-                         [points[i, 2], points[i, 2]],
-                         **po.plot_kwargs))
+            po.axes.plot(
+                [points[i, 0] + errors_up[i, 0], points[i, 0] - errors_down[i, 0]],
+                [points[i, 1], points[i, 1]],
+                [points[i, 2], points[i, 2]],
+                **po.plot_kwargs
+            )
+        )
         artists.append(
-            po.axes.plot([points[i, 0], points[i, 0]],
-                         [points[i, 1] + errors_up[i, 1],
-                          points[i, 1] - errors_down[i, 1]],
-                         [points[i, 2], points[i, 2]],
-                         **po.plot_kwargs))
+            po.axes.plot(
+                [points[i, 0], points[i, 0]],
+                [points[i, 1] + errors_up[i, 1], points[i, 1] - errors_down[i, 1]],
+                [points[i, 2], points[i, 2]],
+                **po.plot_kwargs
+            )
+        )
         artists.append(
-            po.axes.plot([points[i, 0], points[i, 0]],
-                         [points[i, 1], points[i, 1]],
-                         [points[i, 2] + errors_up[i, 2],
-                          points[i, 2] - errors_down[i, 2]],
-                         **po.plot_kwargs))
+            po.axes.plot(
+                [points[i, 0], points[i, 0]],
+                [points[i, 1], points[i, 1]],
+                [points[i, 2] + errors_up[i, 2], points[i, 2] - errors_down[i, 2]],
+                **po.plot_kwargs
+            )
+        )
 
     return artists
 
@@ -636,7 +653,7 @@ def axes_dim(axes):
     """
     Returns int: axes dimension
     """
-    if hasattr(axes, 'get_zlim'):
+    if hasattr(axes, "get_zlim"):
         return 3
     else:
         return 2
@@ -646,7 +663,7 @@ def set_aspect_equal(axes):
     """Fix equal aspect bug for 3D plots."""
 
     if axes_dim(axes) == 2:
-        axes.set_aspect('equal')
+        axes.set_aspect("equal")
         return
 
     xlim = axes.get_xlim3d()
@@ -654,15 +671,18 @@ def set_aspect_equal(axes):
     zlim = axes.get_zlim3d()
 
     from numpy import mean
+
     xmean = mean(xlim)
     ymean = mean(ylim)
     zmean = mean(zlim)
 
-    plot_radius = max([abs(lim - mean_)
-                       for lims, mean_ in ((xlim, xmean),
-                                           (ylim, ymean),
-                                           (zlim, zmean))
-                       for lim in lims])
+    plot_radius = max(
+        [
+            abs(lim - mean_)
+            for lims, mean_ in ((xlim, xmean), (ylim, ymean), (zlim, zmean))
+            for lim in lims
+        ]
+    )
 
     axes.set_xlim3d([xmean - plot_radius, xmean + plot_radius])
     axes.set_ylim3d([ymean - plot_radius, ymean + plot_radius])
@@ -740,9 +760,9 @@ def set_legend(axes, artists, **kwargs):
 
         >> plt.show()
     """
-    table = kwargs.pop('table', False)
-    labels = kwargs.pop('labels', None)
-    ncol = kwargs.pop('ncol', None)
+    table = kwargs.pop("table", False)
+    labels = kwargs.pop("labels", None)
+    ncol = kwargs.pop("ncol", None)
 
     handles = []
     for artist in artists:
@@ -766,16 +786,16 @@ def set_legend(axes, artists, **kwargs):
                 sub_labels = [sub_h.get_label() for sub_h in h]
                 label = sub_labels[0]
                 for sub_label in sub_labels[1:]:
-                    if not sub_label.startswith('_'):
+                    if not sub_label.startswith("_"):
                         label += sub_label
             else:
                 label = h.get_label()
             labels.append(label)
 
     if table and labels is None and ncol is None:
-        table_title = kwargs.pop('table_title', '')
+        table_title = kwargs.pop("table_title", "")
         labels = np.array([h.get_label() for h in handles])
-        labels = [label.split(',') for label in labels]
+        labels = [label.split(",") for label in labels]
         captions_i = []
         captions_j = []
         for label in labels:
@@ -784,16 +804,16 @@ def set_legend(axes, artists, **kwargs):
             if label[1] not in captions_j:
                 captions_j.append(label[1])
 
-        shape = (len(captions_i),
-                 len(captions_j))
+        shape = (len(captions_i), len(captions_j))
 
         # initialize
         shape = np.array(shape)
         handles = np.array(handles)
 
         # create blank rectangle
-        extra = Rectangle((0, 0), 1, 1, fc="w", fill=False, edgecolor='none',
-                          linewidth=0)
+        extra = Rectangle(
+            (0, 0), 1, 1, fc="w", fill=False, edgecolor="none", linewidth=0
+        )
 
         # Create organized list containing all handles for table.
         # Extra represent empty space
@@ -802,12 +822,11 @@ def set_legend(axes, artists, **kwargs):
             i = captions_i.index(label[0])
             j = captions_j.index(label[1])
             if handles_table[i + 1, j + 1] != extra:
-                raise ValueError("Duplicate label {label}"
-                                 .format(**locals()))
+                raise ValueError("Duplicate label {label}".format(**locals()))
             handles_table[i + 1, j + 1] = handle
 
         # Define the label captions
-        labels_table = np.full(shape + 1, '', dtype='S80')
+        labels_table = np.full(shape + 1, "", dtype="S80")
         labels_table[0, 0] = table_title
         labels_table[0, 1:] = captions_j
         labels_table[1:, 0] = captions_i
@@ -815,10 +834,10 @@ def set_legend(axes, artists, **kwargs):
 
         handles = list(handles_table.flat)
         labels = list(labels_table.flat)
-        kwargs['ncol'] = shape[0] + 1
+        kwargs["ncol"] = shape[0] + 1
         # negative numbers in handletextpad move to the right
-        kwargs['handletextpad'] = kwargs.pop('handletextpad', -1.5)
-        kwargs['columnspacing'] = kwargs.pop('columnspacing', 1.5)
+        kwargs["handletextpad"] = kwargs.pop("handletextpad", -1.5)
+        kwargs["columnspacing"] = kwargs.pop("columnspacing", 1.5)
 
     return axes.legend(handles=handles, labels=labels, **kwargs)
 
@@ -828,6 +847,7 @@ class set_zoomable(object):
     Left click a colorbar and release in order to zoom.
     Upper and lower 5% of the colorbar will zoom out.
     """
+
     def __init__(self, cbar):
         self._cbar = cbar
         self._v_press = None
@@ -835,11 +855,11 @@ class set_zoomable(object):
 
         artist = self._cbar.mappable
         self._press_connection_id = artist.axes.figure.canvas.mpl_connect(
-            'button_press_event',
-            partial(self.on_press))
+            "button_press_event", partial(self.on_press)
+        )
         self._release_connection_id = artist.axes.figure.canvas.mpl_connect(
-            'button_release_event',
-            partial(self.on_release))
+            "button_release_event", partial(self.on_release)
+        )
 
     def on_press(self, event):
         if event.inaxes is self._cbar.ax:
@@ -874,10 +894,18 @@ class set_zoomable(object):
         artist.axes.figure.canvas.draw()
 
 
-def set_colorbar(axes, artist, label=None, divide=True,
-                 position='right', size="2%", pad=0.05,
-                 labelpad=None, zoom=False,
-                 **kwargs):
+def set_colorbar(
+    axes,
+    artist,
+    label=None,
+    divide=True,
+    position="right",
+    size="2%",
+    pad=0.05,
+    labelpad=None,
+    zoom=False,
+    **kwargs
+):
     """
     Note:
         Bug found in matplotlib:
@@ -893,19 +921,19 @@ def set_colorbar(axes, artist, label=None, divide=True,
         >> axes.clear()
 
     """
-    ticks_position = 'default'
-    label_position = 'bottom'
+    ticks_position = "default"
+    label_position = "bottom"
     labelpad = 30 if labelpad is None else labelpad
-    if position == 'right':
+    if position == "right":
         rotation = 270
-    elif position == 'left':
+    elif position == "left":
         rotation = 90
-    elif position == 'top':
+    elif position == "top":
         rotation = 0
-        ticks_position = 'top'
-        label_position = 'top'
+        ticks_position = "top"
+        label_position = "top"
         labelpad = 5
-    elif position == 'bottom':
+    elif position == "bottom":
         rotation = 0
     # colorbar
     if divide and axes_dim(axes) == 2:
@@ -916,7 +944,7 @@ def set_colorbar(axes, artist, label=None, divide=True,
         cbar = plt.colorbar(artist, ax=axes, **kwargs)
     cbar.ax.xaxis.set_ticks_position(ticks_position)
     cbar.ax.xaxis.set_label_position(label_position)
-    cbar.ax.tick_params(axis='x', which='major', pad=0)
+    cbar.ax.tick_params(axis="x", which="major", pad=0)
 
     # label
     if label is None:
@@ -941,11 +969,12 @@ def set_labels(axes, *labels):
     if axes_dim(axes) == 3:
         axes.set_zlabel(labels[2])
     elif axes_dim(axes) != 2:
-        raise ValueError("Axis dimensions other than 2 or 3 is not supported"
-                         "for set_labels.")
+        raise ValueError(
+            "Axis dimensions other than 2 or 3 is not supported" "for set_labels."
+        )
 
 
-def set_formatter(sub_axes=None, formatter=dates.DateFormatter('%d-%m-%y')):
+def set_formatter(sub_axes=None, formatter=dates.DateFormatter("%d-%m-%y")):
     if sub_axes is None:
         axes = gca()
         sub_axes = axes.xaxis
@@ -960,10 +989,13 @@ class ScientificFormatter(mpl.ticker.ScalarFormatter):
         ...     label=r"$q_c\;(MW/m^2)$",  # NOQA
         ...     format=rna.plotting.backend.ScientificFormatter(
         ...         None, useMathText=False))
+
     Args:
         oom (int): order of magnitued on the axes
         **kwargs: forwarded to ScalarFormatter
+
     """
+
     def __init__(self, oom=None, **kwargs):
         self._oom = oom
         super(ScientificFormatter, self).__init__(**kwargs)
@@ -980,7 +1012,7 @@ class ScientificFormatter(mpl.ticker.ScalarFormatter):
 # ANIMATION
 
 try:
-    FFMPEGWRITER = manimation.writers['ffmpeg']
+    FFMPEGWRITER = manimation.writers["ffmpeg"]
     FFMPEG = True
 except Exception as err:
     logging.getLogger().warning(str(err))
@@ -991,6 +1023,7 @@ except Exception as err:
 class Writer(FFMPEGWRITER):
     """
     FFMPEGWRITER child
+
     Args:
         **kwargs:
             title (str)
@@ -1010,20 +1043,19 @@ class Writer(FFMPEGWRITER):
         ...         writer.grab_frame()
         ...         axes.clear()
     """
+
     def __init__(self, **kwargs):
         if FFMPEG:
             # set Defaults
             title = kwargs.pop("title", "")
             comment = kwargs.pop("comment", "")
-            artist = kwargs.pop('artist', 'rna plotting module')
+            artist = kwargs.pop("artist", "rna plotting module")
             fps = kwargs.pop("fps", 15)
             if len(kwargs) > 0:
                 raise ValueError("Some Attributes are not used.")
 
             # set up writer
-            metadata = dict(title=title,
-                            artist=artist,
-                            comment=comment)
+            metadata = dict(title=title, artist=artist, comment=comment)
             super(Writer, self).__init__(fps=fps, metadata=metadata)
 
     @contextmanager
@@ -1047,15 +1079,15 @@ class Writer(FFMPEGWRITER):
             log.warn("FFMPEG Writer not available. Nothing is written!")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     import tfields
+
     m = tfields.Mesh3D.grid((0, 2, 2), (0, 1, 3), (0, 0, 1))
     m.maps[0].fields.append(tfields.Tensors(np.arange(m.faces.shape[0])))
-    art1 = m.plot(dim=3, map_index=0, label='twenty')
+    art1 = m.plot(dim=3, map_index=0, label="twenty")
 
     m = tfields.Mesh3D.grid((4, 7, 2), (3, 5, 3), (2, 2, 1))
     m.maps[0].fields.append(tfields.Tensors(np.arange(m.faces.shape[0])))
-    art = m.plot(dim=3, map_index=0, edgecolor='k', vmin=-1, vmax=1,
-                 label="something")
+    art = m.plot(dim=3, map_index=0, edgecolor="k", vmin=-1, vmax=1, label="something")
 
     plot_sphere([7, 0, 1], 3)
